@@ -1,4 +1,3 @@
-import six
 import sqlalchemy as sa
 from sqlalchemy.sql.expression import desc, asc
 
@@ -174,23 +173,18 @@ def make_order_by_deterministic(query):
         return query
 
     order_by = query._order_by[0]
-    if isinstance(order_by, sa.Column):
-        order_by_func = sa.asc
-        column = order_by
-    elif isinstance(order_by, sa.sql.expression.UnaryExpression):
+    if isinstance(order_by, sa.sql.expression.UnaryExpression):
         if order_by.modifier == sa.sql.operators.desc_op:
             order_by_func = sa.desc
         else:
             order_by_func = sa.asc
         column = order_by.get_children()[0]
-    elif isinstance(order_by, six.string_types):
-        raise TypeError(
-            'Order by str is not supported. Use SA Column objects instead.'
-        )
     else:
-        raise TypeError('Only simple columns in query order by are supported.')
+        column = order_by
+        order_by_func = sa.asc
 
-    if has_unique_index(column):
+    # Queries that are ordered by an already
+    if isinstance(column, sa.Column) and has_unique_index(column):
         return query
 
     base_table = get_tables(query._entities[0])[0]
